// Importing required functions from d3 library
import { select, json, geoPath, geoNaturalEarth1} from 'd3';
import {feature} from 'topojson';

// Selecting the SVG element and setting its dimensions
const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

// Creating a new projection
const projection = d3.geoMercator();

// Creating a path generator using the projection
const pathGenerator = geoPath().projection(projection);

// Adding a path for the sphere
svg.append('path')
  .attr('class', 'sphere') // Set the class for the path element
  .attr('d', pathGenerator({type: 'Sphere'})); // Set the d attribute for the path element using the path generator

// Loading the data and drawing the map
json('https://gist.githubusercontent.com/anvesh2129/8a4aaa5ccab0dcf71d93d007142ebe6f/raw/661de052c1849dbd5f5f33658c61cd05a1b3dc67/World_Map.json')
  .then(data => {
    // Parsing the data using the topojson.feature function
    const countries = feature(data, data.objects.countries);
    
    // Data join for the paths, with class and d attributes set using the path generator
    svg.selectAll('path')
      .data(countries.features)
      .enter().append('path')
        .attr('class', 'country')
        .attr('d', pathGenerator);
  });
